//+------------------------------------------------------------------+
//|                                               MAcrossover.mq4    |
//|                                                                  |
//| Check for MA crossover using closed candles.                     |
//+------------------------------------------------------------------+

extern int    fastMA = 10;
extern int    slowMA = 20;
extern color  arrowColorUp = LimeGreen;
extern color  arrowColorDown = PaleVioletRed;
extern color  commentColor = PaleVioletRed;
extern string commentForCrossUp   = "Fast MA crossed slow MA up";
extern string commentForCrossDown = "Fast MA crossed slow MA down";
extern string commentForNoCross   = "no MAs cross yet";

 //+------------------------------------------------------------------+
 //| expert initialization function                                   |
 //+------------------------------------------------------------------+
 int init()
 {
   return(0);
 }
 
 //+------------------------------------------------------------------+
 //| expert deinitialization function                                 |
 //+------------------------------------------------------------------+
 int deinit()
 {
   ObjectDelete("CommentID");
   ObjectDelete("ArrowID");
   return(0);
 }
 
 //+------------------------------------------------------------------+
 //| expert start function                                            |
 //+------------------------------------------------------------------+
 int start()
 {
   static datetime currentBar = 0;
   if  (currentBar == Time[0])  return(0);      // ie Exit
   else currentBar =  Time[0];                  // otherwise continue execution

   int crossover = checkForCrossover();
      ObjectDelete("ArrowID");
      if (crossover == 0) SetComment(commentForNoCross);
      if (crossover == 1) { SetComment(commentForCrossUp);   SetArrow(true); }
      if (crossover == 2) { SetComment(commentForCrossDown); SetArrow(False); }
   return(0);
 }
 
 //+------------------------------------------------------------------+
 //| check for a crossover                                            |
 //+------------------------------------------------------------------+
 int checkForCrossover()
 {
   int isCrossed = 0;
   double fastEma1 = iMA(NULL,0,fastMA,0,MODE_LWMA,PRICE_CLOSE,1);
   double slowEma1 = iMA(NULL,0,slowMA,0,MODE_LWMA,PRICE_CLOSE,1);
   double fastEma2 = iMA(NULL,0,fastMA,0,MODE_LWMA,PRICE_CLOSE,2);
   double slowEma2 = iMA(NULL,0,slowMA,0,MODE_LWMA,PRICE_CLOSE,2);
   double diff1 = fastEma1-slowEma1;
   double diff2 = fastEma2-slowEma2;
   
   if ((diff1*diff2)<0)  // see notes below
   {
     if (fastEma1>slowEma1) isCrossed = 1;
     else                   isCrossed = 2;     
   } 
   return(isCrossed);
}

//------------------------------------------------------------------
//                                                                  
//------------------------------------------------------------------
//
//
//
//
//

void SetComment(string value)
{
   string name = "CommentID";
      ObjectCreate(name,OBJ_LABEL,0,0,0);
         ObjectSet(name,OBJPROP_CORNER,3);
         ObjectSet(name,OBJPROP_COLOR,commentColor);
         ObjectSet(name,OBJPROP_XDISTANCE,15);
         ObjectSet(name,OBJPROP_YDISTANCE,15);
         ObjectSetText(name,value,12,"Arial bold");         
}
void SetArrow(bool isUp)
{
   string name = "ArrowID";
      ObjectCreate(name,OBJ_ARROW,0,0,0);
         ObjectSet(name,OBJPROP_TIME1,Time[1]);
         if (isUp)
         {
            ObjectSet(name,OBJPROP_COLOR,arrowColorUp);
            ObjectSet(name,OBJPROP_PRICE1,Low[1]-iATR(NULL,0,10,0));
            ObjectSet(name,OBJPROP_ARROWCODE,241);
         }
         else
         {
            ObjectSet(name,OBJPROP_COLOR,arrowColorDown);
            ObjectSet(name,OBJPROP_PRICE1,High[1]+iATR(NULL,0,10,0));
            ObjectSet(name,OBJPROP_ARROWCODE,242);
         }            
}